# Generated by Django 3.1.3 on 2020-11-19 19:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ievv_api_key', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='scopedapikey',
            name='base_jwt_payload',
            field=models.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name='scopedapikeyauthenticationlog',
            name='log_data',
            field=models.JSONField(default=dict, null=True),
        ),
    ]
